.. NGPIris documentation master file, created by
   sphinx-quickstart on Fri Sep 27 16:07:28 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to NGPIris's documentation!
===================================

.. toctree::
   :maxdepth: 4
   :caption: Contents:

   NGPIris


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
